@@ -409,11 +409,15 @@ pub async fn upload(
         if UvRetryableStrategy.handle(&result) == Some(Retryable::Transient) {
             let retry_decision = retry_policy.should_retry(start_time, n_past_retries);
             if let reqwest_retry::RetryDecision::Retry { execute_after } = retry_decision {
-                warn_user!("Transient failure while handling response for {registry}; retrying...");
                 reporter.on_upload_complete(idx);
                 let duration = execute_after
                     .duration_since(SystemTime::now())
                     .unwrap_or_else(|_| Duration::default());
+                warn_user!(
+                    "Transient failure while handling response for {}; retrying after {}s...",
+                    registry,
+                    duration.as_secs()
+                );
                 tokio::time::sleep(duration).await;
                 n_past_retries += 1;
                 continue;
