@@ -1,3 +1,4 @@
+use std::num::NonZeroUsize;
 use std::ops::Deref;
 use std::path::{Path, PathBuf};
 use std::time::Duration;
@@ -565,6 +566,13 @@ pub enum Error {
     },
 }
 
+#[derive(Copy, Clone, Debug)]
+pub struct Concurrency {
+    pub downloads: Option<NonZeroUsize>,
+    pub builds: Option<NonZeroUsize>,
+    pub installs: Option<NonZeroUsize>,
+}
+
 /// Options loaded from environment variables.
 ///
 /// This is currently a subset of all respected environment variables, most are parsed via Clap at
@@ -578,6 +586,7 @@ pub struct EnvironmentOptions {
     pub log_context: Option<bool>,
     pub http_timeout: Duration,
     pub upload_http_timeout: Duration,
+    pub concurrency: Concurrency,
     #[cfg(feature = "tracing-durations-export")]
     pub tracing_durations_file: Option<PathBuf>,
 }
@@ -587,11 +596,9 @@ impl EnvironmentOptions {
     pub fn new() -> Result<Self, Error> {
         // Timeout options, matching https://doc.rust-lang.org/nightly/cargo/reference/config.html#httptimeout
         // `UV_REQUEST_TIMEOUT` is provided for backwards compatibility with v0.1.6
-        let http_timeout = parse_integer_environment_variable(EnvVars::UV_HTTP_TIMEOUT)?
-            .or(parse_integer_environment_variable(
-                EnvVars::UV_REQUEST_TIMEOUT,
-            )?)
-            .or(parse_integer_environment_variable(EnvVars::HTTP_TIMEOUT)?)
+        let http_timeout = parse_u64_environment_variable(EnvVars::UV_HTTP_TIMEOUT)?
+            .or(parse_u64_environment_variable(EnvVars::UV_REQUEST_TIMEOUT)?)
+            .or(parse_u64_environment_variable(EnvVars::HTTP_TIMEOUT)?)
             .map(Duration::from_secs);
 
         Ok(Self {
@@ -602,6 +609,15 @@ impl EnvironmentOptions {
             python_install_registry: parse_boolish_environment_variable(
                 EnvVars::UV_PYTHON_INSTALL_REGISTRY,
             )?,
+            concurrency: Concurrency {
+                downloads: parse_non_zero_usize_environment_variable(
+                    EnvVars::UV_CONCURRENT_DOWNLOADS,
+                )?,
+                builds: parse_non_zero_usize_environment_variable(EnvVars::UV_CONCURRENT_BUILDS)?,
+                installs: parse_non_zero_usize_environment_variable(
+                    EnvVars::UV_CONCURRENT_INSTALLS,
+                )?,
+            },
             install_mirrors: PythonInstallMirrors {
                 python_install_mirror: parse_string_environment_variable(
                     EnvVars::UV_PYTHON_INSTALL_MIRROR,
@@ -614,12 +630,10 @@ impl EnvironmentOptions {
                 )?,
             },
             log_context: parse_boolish_environment_variable(EnvVars::UV_LOG_CONTEXT)?,
-            upload_http_timeout: parse_integer_environment_variable(
-                EnvVars::UV_UPLOAD_HTTP_TIMEOUT,
-            )?
-            .map(Duration::from_secs)
-            .or(http_timeout)
-            .unwrap_or(Duration::from_secs(15 * 60)),
+            upload_http_timeout: parse_u64_environment_variable(EnvVars::UV_UPLOAD_HTTP_TIMEOUT)?
+                .map(Duration::from_secs)
+                .or(http_timeout)
+                .unwrap_or(Duration::from_secs(15 * 60)),
             http_timeout: http_timeout.unwrap_or(Duration::from_secs(30)),
             #[cfg(feature = "tracing-durations-export")]
             tracing_durations_file: parse_path_environment_variable(
@@ -702,8 +716,14 @@ fn parse_string_environment_variable(name: &'static str) -> Result<Option<String
     }
 }
 
-/// Parse a integer environment variable.
-fn parse_integer_environment_variable(name: &'static str) -> Result<Option<u64>, Error> {
+fn parse_integer_environment_variable<T>(
+    name: &'static str,
+    err_msg: &'static str,
+) -> Result<Option<T>, Error>
+where
+    T: std::str::FromStr + Copy,
+    <T as std::str::FromStr>::Err: std::fmt::Display,
+{
     let value = match std::env::var(name) {
         Ok(v) => v,
         Err(e) => {
@@ -712,7 +732,7 @@ fn parse_integer_environment_variable(name: &'static str) -> Result<Option<u64>,
                 std::env::VarError::NotUnicode(err) => Err(Error::InvalidEnvironmentVariable {
                     name: name.to_string(),
                     value: err.to_string_lossy().to_string(),
-                    err: "expected an integer".to_string(),
+                    err: err_msg.to_string(),
                 }),
             };
         }
@@ -720,16 +740,29 @@ fn parse_integer_environment_variable(name: &'static str) -> Result<Option<u64>,
     if value.is_empty() {
         return Ok(None);
     }
-    match value.parse::<u64>() {
+
+    match value.parse::<T>() {
         Ok(v) => Ok(Some(v)),
         Err(_) => Err(Error::InvalidEnvironmentVariable {
             name: name.to_string(),
             value,
-            err: "expected an integer".to_string(),
+            err: err_msg.to_string(),
         }),
     }
 }
 
+/// Parse a integer environment variable.
+fn parse_u64_environment_variable(name: &'static str) -> Result<Option<u64>, Error> {
+    parse_integer_environment_variable(name, "expected an integer")
+}
+
+/// Parse a non-zero usize environment variable.
+fn parse_non_zero_usize_environment_variable(
+    name: &'static str,
+) -> Result<Option<NonZeroUsize>, Error> {
+    parse_integer_environment_variable(name, "expected a non-zero positive integer")
+}
+
 #[cfg(feature = "tracing-durations-export")]
 /// Parse a path environment variable.
 fn parse_path_environment_variable(name: &'static str) -> Option<PathBuf> {
